@@ -211,27 +211,27 @@ inline uint32_t serializationLength(const T& t)
 };
 
 #if defined(__arm__) || defined(__arm)
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint8_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int8_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint16_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int16_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint32_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int32_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint64_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int64_t);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(float);
-    ROS_CREATE_SIMPLE_SERIALIZER_ARM(double);
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint8_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int8_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint16_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int16_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint32_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int32_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(uint64_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(int64_t)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(float)
+    ROS_CREATE_SIMPLE_SERIALIZER_ARM(double)
 #else
-    ROS_CREATE_SIMPLE_SERIALIZER(uint8_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(int8_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(uint16_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(int16_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(uint32_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(int32_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(uint64_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(int64_t);
-    ROS_CREATE_SIMPLE_SERIALIZER(float);
-    ROS_CREATE_SIMPLE_SERIALIZER(double);
+    ROS_CREATE_SIMPLE_SERIALIZER(uint8_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(int8_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(uint16_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(int16_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(uint32_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(int32_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(uint64_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(int64_t)
+    ROS_CREATE_SIMPLE_SERIALIZER(float)
+    ROS_CREATE_SIMPLE_SERIALIZER(double)
 #endif
 
 /**
